@@ -1344,18 +1344,18 @@ LIGHTGBM_C_EXPORT int LGBM_NetworkInitWithFunctions(int num_machines,
 * \param[out] out Created REModel
 * \return 0 when succeed, -1 when failure happens
 */
-LIGHTGBM_C_EXPORT int GPB_CreateREModel(int num_data,
-    const int* cluster_ids_data,
+LIGHTGBM_C_EXPORT int GPB_CreateREModel(int32_t num_data,
+    const int32_t* cluster_ids_data,
     const char* re_group_data,
-    int num_re_group,
+    int32_t num_re_group,
     const double* re_group_rand_coef_data,
-    const int* ind_effect_group_rand_coef,
-    int num_re_group_rand_coef,
-    int num_gp,
+    const int32_t* ind_effect_group_rand_coef,
+    int32_t num_re_group_rand_coef,
+    int32_t num_gp,
     const double* gp_coords_data,
     const int dim_gp_coords,
     const double* gp_rand_coef_data,
-    int num_gp_rand_coef,
+    int32_t num_gp_rand_coef,
     const char* cov_fct,
     double cov_fct_shape,
     double cov_fct_taper_range,
@@ -1515,8 +1515,8 @@ LIGHTGBM_C_EXPORT int GPB_GetNumIt(REModelHandle handle,
 * \param covariate_data_pred Covariate data (=independent variables, features) for prediction
 */
 LIGHTGBM_C_EXPORT int GPB_SetPredictionData(REModelHandle handle,
-    int num_data_pred,
-    const int* cluster_ids_data_pred = nullptr,
+    int32_t num_data_pred,
+    const int32_t* cluster_ids_data_pred = nullptr,
     const char* re_group_data_pred = nullptr,
     const double* re_group_rand_coef_data_pred = nullptr,
     double* gp_coords_data_pred = nullptr,
@@ -1552,12 +1552,12 @@ LIGHTGBM_C_EXPORT int GPB_SetPredictionData(REModelHandle handle,
 */
 LIGHTGBM_C_EXPORT int GPB_PredictREModel(REModelHandle handle,
     const double* y_data,
-    int num_data_pred,
+    int32_t num_data_pred,
     double* out_predict,
     bool predict_cov_mat = false,
     bool predict_var = false,
     bool predict_response = false,
-    const int* cluster_ids_data_pred = nullptr,
+    const int32_t* cluster_ids_data_pred = nullptr,
     const char* re_group_data_pred = nullptr,
     const double* re_group_rand_coef_data_pred = nullptr,
     double* gp_coords_pred = nullptr,
