@@ -45,7 +45,6 @@ b_multiple <- qnorm(sim_rand_unif(n=n, init_c=0.8))
 eps_multiple <- as.vector(C_multiple %*% b_multiple)
 
 
-
 # Avoid that long tests get executed on CRAN
 if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
   
@@ -63,7 +62,6 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(dim(gp_model$get_cov_pars())[2], 3)
     expect_equal(dim(gp_model$get_cov_pars())[1], 2)
     expect_equal(gp_model$get_num_optim_iter(), 382)
-    
     # Gradient descent without Nesterov acceleration
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
@@ -71,7 +69,6 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
                                                 delta_rel_conv=1E-6, convergence_criterion = "relative_change_in_parameters"))
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),5E-6)
     expect_equal(gp_model$get_num_optim_iter(), 723)
-    
     # Using a too large learning rate
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE, maxit=1500,
@@ -79,7 +76,6 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
                                                 delta_rel_conv=1E-6, convergence_criterion = "relative_change_in_parameters"))
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),2E-5)
     expect_equal(gp_model$get_num_optim_iter(), 587)
-    
     # Different terminations criterion and a too large learning rate
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
@@ -90,7 +86,6 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(gp_model$get_num_optim_iter(), 277)
     ll <- gp_model$neg_log_likelihood(y=y,cov_pars=gp_model$get_cov_pars()[1,])
     expect_lt(abs(ll-122.7752703),1E-6)
-    
     # Fisher scoring
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y,
@@ -102,8 +97,7 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(class(cov_pars_est), "numeric")
     expect_equal(length(cov_pars_est), 3)
     expect_equal(gp_model$get_num_optim_iter(), 16)
-    
-    # Different termination criterion
+    # Fisher scoring & different termination criterion
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y,
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
@@ -112,7 +106,7 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     cov_pars_other_crit <- c(0.03300593, 0.07725225, 1.07584118, 0.25180563, 0.11357012, 0.03773325)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars_other_crit)),1E-6)
     expect_equal(gp_model$get_num_optim_iter(), 8)
-    
+    # Gradient descent & different termination criterion
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                                 lr_cov = 0.1, use_nesterov_acc = TRUE,
@@ -120,6 +114,14 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     cov_pars_other_crit <- c(0.03958167, 0.08007032, 1.07078222, 0.25358067, 0.11486063, 0.03865198)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars_other_crit)),1E-6)
     expect_equal(gp_model$get_num_optim_iter(), 83)
+    # Nelder-mead
+    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+                           y = y, params = list(optimizer_cov = "nelder_mead"))
+    cov_pars_est <- as.vector(gp_model$get_cov_pars())
+    expect_lt(sum(abs(cov_pars_est-cov_pars[c(1,3,5)])),1E-3)
+    expect_equal(class(cov_pars_est), "numeric")
+    expect_equal(length(cov_pars_est), 3)
+    expect_equal(gp_model$get_num_optim_iter(), 40)
     
     # Prediction from fitted model
     gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
@@ -140,7 +142,7 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
     expect_lt(sum(abs(as.vector(pred$var)-expected_cov[c(1,5,9)])),1E-6)
     
-    # Prediction using given paraneters
+    # Prediction using given parameters
     gp_model <- GPModel(gp_coords = coords, cov_function = "exponential")
     pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
                     cov_pars = c(0.02,1.2,0.9), predict_cov_mat = TRUE)
@@ -182,7 +184,6 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
     expect_lt(sum(abs( as.vector(gp_model$get_coef())-coef)),1E-6)
     expect_equal(gp_model$get_num_optim_iter(), 11)
-    
     # Prediction 
     coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
     X_test <- cbind(rep(1,3),c(-0.5,0.2,0.4))
@@ -193,6 +194,28 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
                       3.469270e-01, 2.686334e-07, 8.317903e-08, 2.686334e-07, 4.255400e-01)
     expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
     expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+    
+    # Gradient descent
+    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+                           y = y, X=X,
+                           params = list(optimizer_cov = "gradient_descent", optimizer_coef = "gradient_descent",
+                                         delta_rel_conv=1E-6, use_nesterov_acc = TRUE, std_dev = FALSE))
+    cov_pars <- c(0.01632592, 0.99743757, 0.09625354)
+    coef <- c(2.301436, 1.899027)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_lt(sum(abs(as.vector(gp_model$get_coef())-coef)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 106)
+
+    # Nelder-Mead
+    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+                           y = y, X=X, params = list(optimizer_cov = "nelder_mead",
+                                                     optimizer_coef = "gradient_descent", maxit=1000))
+    cov_pars <- c(0.007253618, 1.004320456, 0.094662117)
+    coef <- c(2.305755, 1.899809)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_lt(sum(abs(as.vector(gp_model$get_coef())-coef)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 247)
+    
   })
   
 }
@@ -342,8 +365,8 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     
     y <- eps + xi
     # Full model 
-    gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=n-1)
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=n-1), file='NUL')
     fit(gp_model, y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                        lr_cov = 0.1, use_nesterov_acc = TRUE,
                                        acc_rate_cov = 0.5, delta_rel_conv=1E-6,
@@ -354,9 +377,9 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(dim(gp_model$get_cov_pars())[1], 2)
     expect_equal(gp_model$get_num_optim_iter(), 382)
     
-    # Prediction using given paraneters
-    gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=n+2)
+    # Prediction using given parameters
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=n+2), file='NUL')
     coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
     pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
                     cov_pars = c(0.02,1.2,0.9), predict_cov_mat = TRUE,
@@ -373,8 +396,8 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(sum(abs(as.vector(pred$var)-expected_cov[c(1,5,9)])),1E-6)
     
     # Vechia approximation with 30 neighbors
-    gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=30)
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=30), file='NUL')
     fit(gp_model, y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                        lr_cov = 0.1, use_nesterov_acc = TRUE,
                                        acc_rate_cov = 0.5, delta_rel_conv=1E-6,
@@ -406,17 +429,17 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     # expect_equal(gp_model$get_num_optim_iter(), 17)
     
     # Fisher scoring & default ordering
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=30, vecchia_ordering="none", y = y,
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
                                          use_nesterov_acc = FALSE,
                                          delta_rel_conv=1E-6, maxit=100,
-                                         convergence_criterion = "relative_change_in_parameters"))
+                                         convergence_criterion = "relative_change_in_parameters")), file='NUL')
     cov_pars <- c(0.01829104, 0.07043221, 1.06577048, 0.23037437, 0.11335918, 0.03484927)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
     expect_equal(gp_model$get_num_optim_iter(), 19)
     
-    # Prediction using given paraneters
+    # Prediction using given parameters
     pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
                     cov_pars = c(0.02,1.2,0.9), predict_cov_mat = TRUE,
                     vecchia_pred_type = "order_obs_first_cond_obs_only")
@@ -475,12 +498,12 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     
     y <- eps + X%*%beta + xi
     # Fit model
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=n+2,
                            y = y, X=X,
                            params = list(optimizer_cov = "fisher_scoring", optimizer_coef = "wls", std_dev = TRUE,
                                          delta_rel_conv=1E-6, use_nesterov_acc = FALSE,
-                                         convergence_criterion = "relative_change_in_parameters"))
+                                         convergence_criterion = "relative_change_in_parameters")), file='NUL')
     cov_pars <- c(0.008461342, 0.069973492, 1.001562822, 0.214358560, 0.094656409, 0.029400407)
     coef <- c(2.30780026, 0.21365770, 1.89951426, 0.09484768)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
@@ -504,25 +527,25 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
   test_that("Vecchia approximation for Gaussian process model with cluster_id's not constant ", {
     
     y <- eps + xi
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=30,
                            y = y, cluster_ids = cluster_ids,
                            params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                          lr_cov = 0.05, use_nesterov_acc = TRUE,
                                          acc_rate_cov = 0.5, delta_rel_conv=1E-6,
-                                         convergence_criterion = "relative_change_in_parameters"))
+                                         convergence_criterion = "relative_change_in_parameters")), file='NUL')
     cov_pars <- c(0.03359375, 0.07751222, 1.07019293,
                   0.22080542, 0.12201912, 0.03761778)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
     expect_equal(gp_model$get_num_optim_iter(), 662)
     
     # Fisher scoring
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=30,
                            y = y, cluster_ids = cluster_ids,
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
                                          use_nesterov_acc = FALSE, delta_rel_conv=1E-6,
-                                         convergence_criterion = "relative_change_in_parameters"))
+                                         convergence_criterion = "relative_change_in_parameters")), file='NUL')
     cov_pars <- c(0.03359131, 0.07751098, 1.07019567, 0.22080490, 0.12201865, 0.03761748)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-5)
     expect_equal(gp_model$get_num_optim_iter(), 15)
@@ -530,12 +553,12 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     # Prediction
     coord_test <- cbind(c(0.1,0.2,0.1001),c(0.9,0.4,0.9001))
     cluster_ids_pred = c(1,3,1)
-    gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=30, cluster_ids = cluster_ids)
-    pred <- gp_model$predict(y = y, gp_coords_pred = coord_test,
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=30, cluster_ids = cluster_ids), file='NUL')
+    capture.output( pred <- gp_model$predict(y = y, gp_coords_pred = coord_test,
                              cluster_ids_pred = cluster_ids_pred,
                              vecchia_pred_type = "order_obs_first_cond_all",
-                             cov_pars = c(0.1,1,0.15), predict_cov_mat = TRUE)
+                             cov_pars = c(0.1,1,0.15), predict_cov_mat = TRUE), file='NUL')
     expected_mu <- c(-0.01438585, 0.00000000, -0.01500132)
     expected_cov <- c(0.7430552, 0.0000000, 0.6423148, 0.0000000,
                       1.1000000, 0.0000000, 0.6423148, 0.0000000, 0.7434589)
@@ -547,21 +570,21 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
   test_that("Vecchia approximation for Gaussian process model with multiple observations at the same location ", {
     
     y <- eps_multiple + xi
-    gp_model <- fitGPModel(gp_coords = coords_multiple, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords_multiple, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=n-1, y = y,
                            params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                          lr_cov = 0.1, use_nesterov_acc = FALSE,
-                                         delta_rel_conv=1E-6, maxit = 500))
+                                         delta_rel_conv=1E-6, maxit = 500)), file='NUL')
     cov_pars <- c(0.037145465, 0.006065652, 1.151982610, 0.434770575, 0.191648634, 0.102375515)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-4)
     expect_equal(gp_model$get_num_optim_iter(), 12)
     
     # Fisher scoring
-    gp_model <- fitGPModel(gp_coords = coords_multiple, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords_multiple, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=n-1, y = y, 
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
                                          use_nesterov_acc = FALSE, delta_rel_conv=1E-6,
-                                         convergence_criterion = "relative_change_in_parameters"))
+                                         convergence_criterion = "relative_change_in_parameters")), file='NUL')
     cov_pars <- c(0.037136462, 0.006064181, 1.153630335, 0.435788570, 0.192080613, 0.102631006)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-5)
     expect_equal(gp_model$get_num_optim_iter(), 14)
@@ -569,8 +592,8 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     # Prediction
     coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
     cluster_ids_pred = c(1,3,1)
-    gp_model <- GPModel(gp_coords = coords_multiple, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=n+2)
+    capture.output( gp_model <- GPModel(gp_coords = coords_multiple, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=n+2), file='NUL')
     pred <- gp_model$predict(y = y, gp_coords_pred = coord_test,
                              vecchia_pred_type = "order_obs_first_cond_all",
                              cov_pars = c(0.1,1,0.15), predict_cov_mat = TRUE)
@@ -588,12 +611,12 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     
     y <- eps_svc + xi
     # Fit model using gradient descent with Nesterov acceleration
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=n-1,
                            gp_rand_coef_data = Z_SVC, y = y,
                            params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
                                          lr_cov = 0.1, use_nesterov_acc = TRUE,
-                                         acc_rate_cov = 0.5, maxit=10))
+                                         acc_rate_cov = 0.5, maxit=10)), file='NUL')
     expected_values <- c(0.25740068, 0.22608704, 0.83503539, 0.41896403, 0.15039055,
                          0.10090869, 1.61010233, 0.84207763, 0.09015444, 0.07106099,
                          0.25064640, 0.62279880, 0.08720822, 0.32047865)
@@ -601,8 +624,8 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(gp_model$get_num_optim_iter(), 10)
     
     # Prediction
-    gp_model <- GPModel(gp_coords = coords, gp_rand_coef_data = Z_SVC, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=n+2)
+    capture.output( gp_model <- GPModel(gp_coords = coords, gp_rand_coef_data = Z_SVC, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=n+2), file='NUL')
     coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
     Z_SVC_test <- cbind(c(0.1,0.3,0.7),c(0.5,0.2,0.4))
     pred <- gp_model$predict(y = y, gp_coords_pred = coord_test,
@@ -616,11 +639,11 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
     
     # Fisher scoring
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=n-1,
                            gp_rand_coef_data = Z_SVC, y = y,
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
-                                         use_nesterov_acc= FALSE, maxit=5))
+                                         use_nesterov_acc= FALSE, maxit=5)), file='NUL')
     expected_values <- c(0.000242813, 0.197623969, 1.120356660, 0.442501100,
                          0.141084495, 0.070778399, 1.670556231, 0.798785653, 0.055598038,
                          0.047379252, 0.430573036, 0.605871724, 0.038976112, 0.116595965)
@@ -632,11 +655,11 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(abs(nll-149.4422184),1E-5)
     
     # Fit model using gradient descent with Nesterov acceleration
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=30,
                            gp_rand_coef_data = Z_SVC, y = y,
                            params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
-                                         lr_cov = 0.1, use_nesterov_acc = FALSE, maxit=10))
+                                         lr_cov = 0.1, use_nesterov_acc = FALSE, maxit=10)), file='NUL')
     expected_values <- c(0.40353068, 0.25914955, 0.70029206, 0.42641715, 0.16737937,
                          0.12728492, 1.14005726, 0.80008664, 0.11213991, 0.11988861,
                          0.49234325, 0.70169773, 0.08919812, 0.20748266)
@@ -644,8 +667,8 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_equal(gp_model$get_num_optim_iter(), 10)
     
     # Prediction
-    gp_model <- GPModel(gp_coords = coords, gp_rand_coef_data = Z_SVC, cov_function = "exponential",
-                        vecchia_approx=TRUE, num_neighbors=30)
+    capture.output( gp_model <- GPModel(gp_coords = coords, gp_rand_coef_data = Z_SVC, cov_function = "exponential",
+                        vecchia_approx=TRUE, num_neighbors=30), file='NUL')
     coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
     Z_SVC_test <- cbind(c(0.1,0.3,0.7),c(0.5,0.2,0.4))
     pred <- gp_model$predict(y = y, gp_coords_pred = coord_test,
@@ -659,11 +682,11 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
     
     # Fisher scoring
-    gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential",
                            vecchia_approx=TRUE, num_neighbors=30,
                            gp_rand_coef_data = Z_SVC, y = y,
                            params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
-                                         use_nesterov_acc= FALSE, maxit=5))
+                                         use_nesterov_acc= FALSE, maxit=5)), file='NUL')
     expected_values <- c(0.04427393, 0.20241802, 0.99631971, 0.43532853, 0.17012209,
                          0.09359131, 1.40235416, 0.78811422, 0.07835884, 0.07553935,
                          0.77593979, 0.64290472, 0.03673858, 0.07640891)
@@ -675,5 +698,120 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     expect_lt(abs(nll-152.6033062),1E-6)
   })
   
+  test_that("Wendland covariance function for Gaussian process model ", {
+    
+    y <- eps + xi
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "wendland", cov_fct_shape=0, cov_fct_taper_range=0.1), 
+                    file='NUL')
+    fit(gp_model, y = y, params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
+                                       lr_cov = 0.1, use_nesterov_acc = TRUE,
+                                       acc_rate_cov = 0.5))
+    cov_pars <- c(0.002911765, 0.116338096, 0.993996193, 0.211276385)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 280)
+    # Prediction using given parameters
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "wendland", cov_fct_shape=1, cov_fct_taper_range=2), 
+                    file='NUL')
+    coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
+    pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
+                    cov_pars = c(0.02,1.2), predict_cov_mat = TRUE)
+    expected_mu <- c(-0.008405567, 1.493836307, 0.720565199)
+    expected_cov <- c(2.933992e-02, 2.223241e-06, 1.352544e-05, 2.223241e-06, 2.496193e-02,
+                      1.130906e-05, 1.352544e-05, 1.130906e-05, 2.405649e-02)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+    # Prediction of variances only
+    pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
+                    cov_pars = c(0.02,1.2), predict_var = TRUE)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$var)-expected_cov[c(1,5,9)])),1E-6)
+    # Fisher scoring
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "wendland", 
+                           cov_fct_shape=0, cov_fct_taper_range=0.1, y = y,
+                           params = list(optimizer_cov = "fisher_scoring", std_dev = TRUE,
+                                         use_nesterov_acc = FALSE,
+                                         delta_rel_conv=1E-6)), file='NUL')
+    cov_pars <- c(3.079098e-193, 1.142352e-01, 9.935983e-01, 2.094882e-01)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 7)
+    # Evaluate negative log-likelihood
+    nll <- gp_model$neg_log_likelihood(cov_pars=c(0.02,1.2),y=y)
+    expect_lt(abs(nll-136.9508962),1E-6)
+    
+    # Other Taper shapes
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "wendland", 
+                           cov_fct_shape=1, cov_fct_taper_range=0.15, y = y,
+                           params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
+                                         lr_cov = 0.1, use_nesterov_acc = TRUE,
+                                         acc_rate_cov = 0.5)), file='NUL')
+    cov_pars <- c(0.0564441, 0.0497191, 0.9921285, 0.1752661)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 19)
+    pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
+                    cov_pars = c(0.02,1.2), predict_cov_mat = TRUE)
+    expected_mu <- c(-0.007404038, 1.487424320, 0.200022114)
+    expected_cov <- c(1.113020e+00, -6.424533e-30, -4.186440e-22, -6.424533e-30, 3.522739e-01,
+                      9.018454e-10, -4.186440e-22, 9.018454e-10, 6.092985e-01)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+    # Other Taper shapes
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "wendland", 
+                           cov_fct_shape=2, cov_fct_taper_range=0.08, y = y,
+                           params = list(optimizer_cov = "gradient_descent", std_dev = TRUE,
+                                         lr_cov = 0.1, use_nesterov_acc = TRUE,
+                                         acc_rate_cov = 0.5)), file='NUL')
+    cov_pars <- c(0.00327103, 0.06579668, 1.08812978, 0.18151366)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 187)
+    pred <- predict(gp_model, y=y, gp_coords_pred = coord_test,
+                    cov_pars = c(0.02,1.2), predict_cov_mat = TRUE)
+    expected_mu <- c(-2.314198e-05, 8.967992e-01, 2.430054e-02)
+    expected_cov <- c(1.2200000, 0.0000000, 0.0000000, 0.0000000, 0.9024792, 0.0000000, 0.0000000, 0.0000000, 1.1887157)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+  })
+  
+  test_that("Tapering ", {
+
+    y <- eps + xi
+    # Estimation: large taper range
+    capture.output( gp_model <- GPModel(gp_coords = coords, cov_function = "exponential_tapered",
+                                        cov_fct_shape=0, cov_fct_taper_range=10) )
+    fit(gp_model, y = y, params = list(optimizer_cov = "nelder_mead", std_dev = TRUE))
+    cov_pars <- c(0.03273474, 0.07718108, 1.07546705, 0.25147762, 0.11602226, 0.03941366)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 48)
+    # Prediction
+    coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
+    pred <- predict(gp_model, y=y, gp_coords_pred = coord_test, predict_cov_mat = TRUE)
+    expected_mu <- c(0.06956388, 1.61286103, 0.44047689)
+    expected_cov <- c(6.220207e-01, 2.020366e-05, 2.264985e-07, 2.020366e-05, 3.536331e-01, 8.450109e-07, 2.264985e-07, 8.450109e-07, 4.203457e-01)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+
+    # With regression term
+    y <- eps + X%*%beta + xi
+    # Fit model
+    capture.output( gp_model <- fitGPModel(gp_coords = coords, cov_function = "exponential_tapered",
+                           y = y, X=X, cov_fct_shape=0, cov_fct_taper_range=10,
+                           params = list(optimizer_cov = "fisher_scoring", optimizer_coef = "wls",
+                                         delta_rel_conv=1E-6, use_nesterov_acc = FALSE, std_dev = TRUE)) )
+    cov_pars <- c(0.008487178, 0.069981873, 1.001585339, 0.214371248, 0.096500576, 0.030554379)
+    coef <- c(2.30777062, 0.21365165, 1.89948870, 0.09484872)
+    expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-cov_pars)),1E-6)
+    expect_lt(sum(abs( as.vector(gp_model$get_coef())-coef)),1E-6)
+    expect_equal(gp_model$get_num_optim_iter(), 8)
+    # Prediction 
+    coord_test <- cbind(c(0.1,0.2,0.7),c(0.9,0.4,0.55))
+    X_test <- cbind(rep(1,3),c(-0.5,0.2,0.4))
+    pred <- predict(gp_model, gp_coords_pred = coord_test,
+                    X_pred = X_test, predict_cov_mat = TRUE)
+    expected_mu <- c(1.196989, 4.063352, 3.156397)
+    expected_cov <- c(6.305291e-01, 1.361678e-05, 8.316878e-08, 1.361678e-05, 3.469265e-01, 2.688201e-07, 8.316878e-08, 2.688201e-07, 4.255276e-01)
+    expect_lt(sum(abs(pred$mu-expected_mu)),1E-6)
+    expect_lt(sum(abs(as.vector(pred$cov)-expected_cov)),1E-6)
+
+  })
+  
 }
 
